<?php

/**
 * @file
 * Integration with File Entity module for display.
 */

/**
 * Implements hook_file_formatter_info().
 */
function media_auvio_file_formatter_info() {
  $formatters = array();
  $formatters['media_auvio_video'] = array(
    'label' => t('Auvio Video'),
    'file types' => array('video'),
    'default settings' => array(
      'width' => 640,
      'height' => 360,
    ),
    'view callback' => 'media_auvio_file_formatter_video_view',
    'settings callback' => 'media_auvio_file_formatter_video_settings',
  );
  return $formatters;
}

/**
 * Implements hook_file_formatter_FORMATTER_view().
 */
function media_auvio_file_formatter_video_view($file, $display, $langcode) {
  $scheme = file_uri_scheme($file->uri);
  // WYSIWYG does not yet support video inside a running editor instance.
  if ($scheme == 'auvio' && empty($file->override['wysiwyg'])) {
    $element = array(
      '#theme' => 'media_auvio_video',
      '#uri' => $file->uri,
      '#options' => array(),
    );
    foreach (array('width', 'height') as $setting) {
      $element['#options'][$setting] = isset($file->override[$setting]) ? $file->override[$setting] : $display['settings'][$setting];
    }
    return $element;
  }
}

/**
 * Implements hook_file_formatter_FORMATTER_settings().
 */
function media_auvio_file_formatter_video_settings($form, &$form_state, $settings) {
  $element = array();
  $element['width'] = array(
    '#title' => t('Width'),
    '#type' => 'textfield',
    '#default_value' => $settings['width'],
  );
  $element['height'] = array(
    '#title' => t('Height'),
    '#type' => 'textfield',
    '#default_value' => $settings['height'],
  );
  return $element;
}

/**
 * Implements hook_file_default_displays().
 */
function media_auvio_file_default_displays() {
  $default_displays = array();

  // Default settings for displaying as a video.
  $default_video_settings = array(
    'media_large' => array(
      'width' => 640,
      'height' => 480,
    ),
    'media_original' => array(
      'width' => 640,
      'height' => 480,
    ),
  );
  foreach ($default_video_settings as $view_mode => $settings) {
    $display_name = 'video__' . $view_mode . '__media_auvio_video';
    $default_displays[$display_name] = (object) array(
      'api_version' => 1,
      'name' => $display_name,
      'status' => 1,
      'weight' => 1,
      'settings' => $settings,
    );
  }

  return $default_displays;
}
